Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(319)

Unified Diff: media/cast/logging/logging_raw.h

Issue 136903003: cast: Wire upp logging to be sent over RTCP between receiver and sender. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Merge TOT Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/cast/logging/logging_impl.cc ('k') | media/cast/logging/logging_raw.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/cast/logging/logging_raw.h
diff --git a/media/cast/logging/logging_raw.h b/media/cast/logging/logging_raw.h
index 79111785e84fb336f8a814312581ed9a1b55581b..504a60c911f5ff4c7440c974bdd7498e64189e2f 100644
--- a/media/cast/logging/logging_raw.h
+++ b/media/cast/logging/logging_raw.h
@@ -24,7 +24,7 @@ namespace cast {
class LoggingRaw : public base::NonThreadSafe,
public base::SupportsWeakPtr<LoggingRaw> {
public:
- LoggingRaw();
+ explicit LoggingRaw(bool is_sender);
~LoggingRaw();
// Inform of new event: three types of events: frame, packets and generic.
@@ -66,8 +66,10 @@ class LoggingRaw : public base::NonThreadSafe,
PacketRawMap GetPacketData() const;
GenericRawMap GetGenericData() const;
+ AudioRtcpRawMap GetAndResetAudioRtcpData();
+ VideoRtcpRawMap GetAndResetVideoRtcpData();
- // Reset all log data.
+ // Reset all log data; except the Rtcp copies.
void Reset();
private:
@@ -76,9 +78,18 @@ class LoggingRaw : public base::NonThreadSafe,
uint32 frame_id,
uint32 rtp_timestamp);
+ void InsertRtcpFrameEvent(const base::TimeTicks& time_of_event,
+ CastLoggingEvent event,
+ uint32 rtp_timestamp,
+ base::TimeDelta delay);
+
+ const bool is_sender_;
FrameRawMap frame_map_;
PacketRawMap packet_map_;
GenericRawMap generic_map_;
+ AudioRtcpRawMap audio_rtcp_map_;
+ VideoRtcpRawMap video_rtcp_map_;
+
base::WeakPtrFactory<LoggingRaw> weak_factory_;
DISALLOW_COPY_AND_ASSIGN(LoggingRaw);
« no previous file with comments | « media/cast/logging/logging_impl.cc ('k') | media/cast/logging/logging_raw.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698